@@ -11,7 +11,7 @@ gi.require_version("Gtk", "3.0")
 gi.require_version('XApp', '1.0')
 from gi.repository import Gtk, Gdk, Gio, XApp, GLib
 
-from common import async, idle, InfoReportContainer, INFO_DIR
+from common import idle, InfoReportContainer, INFO_DIR
 
 setproctitle.setproctitle("mintreport-tray")
 
@@ -42,7 +42,7 @@ class MyApplication(Gtk.Application):
         Gtk.Application.__init__(self, application_id=application_id, flags=flags)
         self.connect("activate", self.activate)
 
-        self.settings = Gio.Settings("com.linuxmint.report")
+        self.settings = Gio.Settings(schema_id="com.linuxmint.report")
 
         # Status icon
         self.menu = Gtk.Menu()
@@ -95,7 +95,7 @@ class MyApplication(Gtk.Application):
             print("Already running!")
 
     def load_info(self):
-        pertinent_reports = []
+        found_pertinent_report = False
         if os.path.exists(INFO_DIR):
             ignored_paths = self.settings.get_strv("ignored-reports")
             for dir_name in sorted(os.listdir(INFO_DIR)):
@@ -105,26 +105,17 @@ class MyApplication(Gtk.Application):
                     try:
                         report = InfoReportContainer(uuid, path)
                         if report.instance.is_pertinent():
-                            pertinent_reports.append(report)
-                            if len(pertinent_reports) > 1:
-                                # If we detect more than 1 report, we don't need
-                                # to go further, we'll show that multiple
-                                # reports are available..
-                                break
+                            found_pertinent_report = True
+                            break
                     except Exception as e:
                         print("Failed to load report %s: \n%s\n" % (dir_name, e))
 
-        if len(pertinent_reports) == 0:
-            self.status_icon.set_visible(False)
-        elif len(pertinent_reports) == 1:
+        if found_pertinent_report:
             self.status_icon.set_visible(True)
-            report = pertinent_reports[0]
-            self.status_icon.set_icon_name(report.instance.icon)
-            self.status_icon.set_tooltip_text(report.instance.title)
+            self.status_icon.set_icon_name("mintreport-symbolic")
+            self.status_icon.set_tooltip_text(_("Some system reports require your attention"))
         else:
-            self.status_icon.set_visible(True)
-            self.status_icon.set_icon_name("dialog-warning-symbolic")
-            self.status_icon.set_tooltip_text(_("Some problems were detected which require your attention"))
+            self.status_icon.set_visible(False)
 
         return True
 
